@@ -104,7 +104,8 @@ def get_all_sri_hashes():
     global _SRI_HASHES
 
     if not _SRI_HASHES:
-        _SRI_HASHES = json.load(open(join(ROOT_DIR, "_sri.json")))
+        with open(join(ROOT_DIR, "_sri.json")) as f:
+            _SRI_HASHES = json.load(f)
 
     return dict(_SRI_HASHES)
 
@@ -126,6 +127,9 @@ def get_sri_hashes_for_version(version):
     Returns:
         dict
 
+    Raises:
+        KeyError: if the specified version does not exist
+
     Example:
 
         The returned dict for a single version will map filenames for that
@@ -138,8 +142,6 @@ def get_sri_hashes_for_version(version):
                 'bokeh-1.4.0.min.js': 'mdMpUZqu5U0cV1pLU9Ap/3jthtPth7yWSJTu1ayRgk95qqjLewIkjntQDQDQA5cZ',
                 'bokeh-api-1.4.0.js': 'Y3kNQHt7YjwAfKNIzkiQukIOeEGKzUU3mbSrraUl1KVfrlwQ3ZAMI1Xrw5o3Yg5V',
                 'bokeh-api-1.4.0.min.js': '4oAJrx+zOFjxu9XLFp84gefY8oIEr75nyVh2/SLnyzzg9wR+mXXEi+xyy/HzfBLM',
-                'bokeh-gl-1.4.0.js': '/+5P6xEUbH87YpzmmpvP7veStj9hr1IBz+r/5oBPr9WwMIft5H4rEJCnyRJsgdRz',
-                'bokeh-gl-1.4.0.min.js': 'nGZaob7Ort3hHvecwVIYtti+WDUaCkU+19+OuqX4ZWzw4ZsDQC2XRbsLEJ1OhDal',
                 'bokeh-tables-1.4.0.js': 'I2iTMWMyfU/rzKXWJ2RHNGYfsXnyKQ3YjqQV2RvoJUJCyaGBrp0rZcWiTAwTc9t6',
                 'bokeh-tables-1.4.0.min.js': 'pj14Cq5ZSxsyqBh+pnL2wlBS3UX25Yz1gVxqWkFMCExcnkN3fl4mbOF8ZUKyh7yl',
                 'bokeh-widgets-1.4.0.js': 'scpWAebHEUz99AtveN4uJmVTHOKDmKWnzyYKdIhpXjrlvOwhIwEWUrvbIHqA0ke5',
@@ -198,7 +200,7 @@ def verify_sri_hashes():
     if bad:
         raise RuntimeError(f"SRI Hash mismatches in the package: {bad!r}")
 
-class BaseResources(object):
+class BaseResources:
     _default_root_dir = "."
     _default_root_url = DEFAULT_SERVER_HTTP_URL
 
@@ -312,7 +314,9 @@ class BaseResources(object):
 
     def _file_paths(self, kind):
         minified = ".min" if not self.dev and self.minified else ""
-        files = ["%s%s.%s" % (component, minified, kind) for component in self.components(kind)]
+        legacy = ".legacy" if self.legacy else ""
+
+        files = [f"{component}{legacy}{minified}.{kind}" for component in self.components(kind)]
         paths = [join(self.base_dir, kind, file) for file in files]
         return paths
 
@@ -343,7 +347,7 @@ class BaseResources(object):
     def _resolve(self, kind):
         paths = self._file_paths(kind)
         files, raw = [], []
-        hashes = None
+        hashes = {}
 
         if self.mode == "inline":
             raw = [self._inline(path) for path in paths]
@@ -423,7 +427,7 @@ class JSResources(BaseResources):
 
     """
 
-    _js_components = ["bokeh", "bokeh-widgets", "bokeh-tables", "bokeh-gl"]
+    _js_components = ["bokeh", "bokeh-widgets", "bokeh-tables"]
 
     # Properties --------------------------------------------------------------
 
@@ -584,7 +588,7 @@ class Resources(JSResources, CSSResources):
 # -----------------------------------------------------------------------------
 
 
-class _SessionCoordinates(object):
+class _SessionCoordinates:
     """ Internal class used to parse kwargs for server URL, app_path, and session_id."""
 
     def __init__(self, **kwargs):
@@ -665,7 +669,6 @@ def _get_cdn_urls(version=None, minified=True, legacy=False):
     }
 
     if len(__version__.split("-")) > 1:
-        log.debug("Getting CDN URL for local dev version may not produce usable URL")
         result["messages"].append(
             {
                 "type": "warn",
@@ -676,7 +679,7 @@ def _get_cdn_urls(version=None, minified=True, legacy=False):
             }
         )
 
-    if is_full_release():
+    if is_full_release(version):
         sri_hashes = get_sri_hashes_for_version(version)
         result['hashes'] = lambda components, kind: {mk_url(component, kind): sri_hashes[mk_filename(component, kind)] for component in components}
 
