@@ -1,13 +1,44 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 ''' Provide classes to represent callback code that can be associate with
 Bokeh Documents and Sessions.
 
 '''
-from __future__ import absolute_import
 
+#-----------------------------------------------------------------------------
+# Boilerplate
+#-----------------------------------------------------------------------------
+import logging # isort:skip
+log = logging.getLogger(__name__)
+
+#-----------------------------------------------------------------------------
+# Imports
+#-----------------------------------------------------------------------------
+
+# Bokeh imports
 from ..util.serialization import make_id
 from ..util.tornado import _CallbackGroup
 
-class SessionCallback(object):
+#-----------------------------------------------------------------------------
+# Globals and constants
+#-----------------------------------------------------------------------------
+
+__all__ = (
+    'NextTickCallback',
+    'PeriodicCallback',
+    'SessionCallback',
+    'TimeoutCallback',
+)
+
+#-----------------------------------------------------------------------------
+# Dev API
+#-----------------------------------------------------------------------------
+
+class SessionCallback:
     ''' A base class for callback objects associated with Bokeh Documents
     and Sessions.
 
@@ -45,8 +76,12 @@ class SessionCallback(object):
         ''' Dev API used to wrap the callback with decorators. '''
         raise NotImplementedError("_copy_with_changed_callback")
 
+#-----------------------------------------------------------------------------
+# General API
+#-----------------------------------------------------------------------------
+
 class NextTickCallback(SessionCallback):
-    ''' Represent a callback to execute on the next IOLoop "tick".
+    ''' Represent a callback to execute on the next ``IOLoop`` "tick".
 
     '''
     def __init__(self, document, callback, id=None):
@@ -60,14 +95,14 @@ class NextTickCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(NextTickCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
 
     def _copy_with_changed_callback(self, new_callback):
         ''' Dev API used to wrap the callback with decorators. '''
         return NextTickCallback(self._document, new_callback, self._id)
 
 class PeriodicCallback(SessionCallback):
-    ''' Represent a callback to execute periodically on the IOLoop at a
+    ''' Represent a callback to execute periodically on the ``IOLoop`` at a
     specified periodic time interval.
 
     '''
@@ -84,7 +119,7 @@ class PeriodicCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(PeriodicCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
         self._period = period
 
     @property
@@ -100,7 +135,7 @@ class PeriodicCallback(SessionCallback):
         return PeriodicCallback(self._document, new_callback, self._period, self._id)
 
 class TimeoutCallback(SessionCallback):
-    ''' Represent a callback to execute once on the IOLoop after a specifeed
+    ''' Represent a callback to execute once on the ``IOLoop`` after a specified
     time interval passes.
 
     '''
@@ -117,7 +152,7 @@ class TimeoutCallback(SessionCallback):
             id (str, optional) :
 
         '''
-        super(TimeoutCallback, self).__init__(document, callback, id)
+        super().__init__(document, callback, id)
         self._timeout = timeout
 
     @property
@@ -131,7 +166,11 @@ class TimeoutCallback(SessionCallback):
         ''' Dev API used to wrap the callback with decorators. '''
         return TimeoutCallback(self._document, new_callback, self._timeout, self._id)
 
-class _DocumentCallbackGroup(object):
+#-----------------------------------------------------------------------------
+# Private API
+#-----------------------------------------------------------------------------
+
+class _DocumentCallbackGroup:
     '''
 
     '''
@@ -185,3 +224,7 @@ class _DocumentCallbackGroup(object):
                 self._group.remove_next_tick_callback(callback_obj.id)
         except ValueError:
             pass
+
+#-----------------------------------------------------------------------------
+# Code
+#-----------------------------------------------------------------------------
