@@ -98,7 +98,7 @@ class SessionConsumer(AsyncHttpConsumer, ConsumerHelper):
     application_context: ApplicationContext
 
     def __init__(self, scope: Dict[str, Any]) -> None:
-        super(SessionConsumer, self).__init__(scope)
+        super().__init__(scope)
 
         kwargs = self.scope["url_route"]["kwargs"]
         self.application_context = kwargs["app_context"]
@@ -108,7 +108,8 @@ class SessionConsumer(AsyncHttpConsumer, ConsumerHelper):
             self.application_context._loop = IOLoop.current()
 
     async def _get_session(self) -> ServerSession:
-        session_id = generate_session_id(secret_key=None, signed=False)
+        session_id = self.arguments.get('bokeh-session-id',
+                                        generate_session_id(secret_key=None, signed=False))
         payload = {'headers': {k.decode('utf-8'): v.decode('utf-8')
                                for k, v in self.request.headers},
                    'cookies': dict(self.request.cookies)}
@@ -143,7 +144,7 @@ class AutoloadJsConsumer(SessionConsumer):
         bundle = bundle_for_objs_and_resources(None, resources)
 
         render_items = [RenderItem(token=session.token, elementid=element_id, use_for_title=False)]
-        bundle.add(Script(script_for_render_items(None, render_items, app_path=app_path, absolute_url=absolute_url)))
+        bundle.add(Script(script_for_render_items({}, render_items, app_path=app_path, absolute_url=absolute_url)))
 
         js = AUTOLOAD_JS.render(bundle=bundle, elementid=element_id)
         headers = [
@@ -172,7 +173,7 @@ class WSConsumer(AsyncWebsocketConsumer, ConsumerHelper):
     application_context: ApplicationContext
 
     def __init__(self, scope: Dict[str, Any]) -> None:
-        super(WSConsumer, self).__init__(scope)
+        super().__init__(scope)
 
         kwargs = self.scope['url_route']["kwargs"]
         self.application_context = kwargs["app_context"]
@@ -196,7 +197,7 @@ class WSConsumer(AsyncWebsocketConsumer, ConsumerHelper):
             self.close()
             raise RuntimeError("No token received in subprotocol header")
 
-        now = calendar.timegm(dt.datetime.now().utctimetuple())
+        now = calendar.timegm(dt.datetime.utcnow().utctimetuple())
         payload = get_token_payload(token)
         if 'session_expiry' not in payload:
             self.close()
