@@ -36,7 +36,7 @@ import bokeh.io.util as biu # isort:skip
 #-----------------------------------------------------------------------------
 
 def test_detect_current_filename() -> None:
-    assert biu.detect_current_filename().endswith(("py.test", "pytest", "py.test-script.py"))
+    assert biu.detect_current_filename().endswith(("py.test", "pytest", "py.test-script.py", "pytest-script.py"))
 
 @patch('bokeh.io.util.NamedTemporaryFile')
 def test_temp_filename(mock_tmp) -> None:
