@@ -18,6 +18,8 @@ import pytest ; pytest
 import json
 import logging
 import os
+import sys
+from subprocess import run
 
 # Bokeh imports
 from _util_server import http_get, url
@@ -39,6 +41,11 @@ logging.basicConfig(level=logging.DEBUG)
 # General API
 #-----------------------------------------------------------------------------
 
+@pytest.mark.skipif(sys.platform != "win32" or sys.version_info < (3, 8), reason="event loop test only for win, py>=3.8")
+def test_windows_event_loop_fixup():
+    proc = run([sys.executable, "-c", "import asyncio, sys; import bokeh.server.tornado; sys.exit(int(isinstance(asyncio.get_event_loop_policy(), asyncio.WindowsProactorEventLoopPolicy)))"'']) # noqa
+    assert proc.returncode == 0, "bokeh.server did not fixup windows event loop"
+
 def test_default_resources(ManagedServerLoop) -> None:
     application = Application()
     with ManagedServerLoop(application) as server:
