@@ -28,7 +28,7 @@ import bokeh.util.string as bus # isort:skip
 # General API
 #-----------------------------------------------------------------------------
 
-class Test_format_doctring(object):
+class Test_format_docstring:
     def test_no_argument(self) -> None:
         doc__ = "hello world"
         assert bus.format_docstring(doc__) == doc__
@@ -47,7 +47,7 @@ class Test_format_doctring(object):
         doc__ = None
         assert bus.format_docstring(doc__, 'hello ', as_parameter='world') == None
 
-class Test_format_url_query_arguments(object):
+class Test_format_url_query_arguments:
     def test_no_arguments(self) -> None:
         assert bus.format_url_query_arguments("url") == "url"
 
@@ -62,7 +62,7 @@ class Test_format_url_query_arguments(object):
         args = dict(foo="10.2", bar="a=b", baz="a?b", quux="a@@ b")
         assert bus.format_url_query_arguments("url", args) == "url?foo=10.2&bar=a%3Db&baz=a%3Fb&quux=a%40%40+b"
 
-class Test_indent(object):
+class Test_indent:
     TEXT = "some text\nto indent\n  goes here"
 
     def test_default_args(self) -> None:
@@ -74,8 +74,8 @@ class Test_indent(object):
     def test_with_ch(self) -> None:
         assert bus.indent(self.TEXT, ch="-") == "--some text\n--to indent\n--  goes here"
 
-class Test_nice_join(object):
 
+class Test_nice_join:
     def test_default(self) -> None:
         assert bus.nice_join(["one"]) == "one"
         assert bus.nice_join(["one", "two"]) == "one or two"
